@@ -2,9 +2,9 @@
 
 use strict;
 use Glib ':constants';
-use Gtk2 -init;
+use Gtk3 -init;
 
-use Data::TreeDumper::Renderer::GTK ; # Gtk2::TreeView derived class
+use Data::TreeDumper::Renderer::GTK ; # Gtk3::TreeView derived class
 
 # some silly test data
 my %data = (
@@ -27,15 +27,15 @@ my $treedumper = Data::TreeDumper::Renderer::GTK->new
 			dumper_setup => {DISPLAY_PERL_SIZE => 1}
 			);
 			
-$treedumper->modify_font(Gtk2::Pango::FontDescription->from_string ('monospace'));
+$treedumper->modify_font(Pango::FontDescription::from_string ('monospace'));
 $treedumper->expand_all;
 
 # some boilerplate to get the widget onto the screen...
-my $window = Gtk2::Window->new;
+my $window = Gtk3::Window->new;
 $window->set_default_size (400, 500);
-$window->signal_connect (destroy => sub { Gtk2->main_quit });
+$window->signal_connect (destroy => sub { Gtk3->main_quit });
 
-my $scroller = Gtk2::ScrolledWindow->new;
+my $scroller = Gtk3::ScrolledWindow->new;
 $scroller->set_policy ('automatic', 'automatic');
 $scroller->set_shadow_type ('in');
 $scroller->add ($treedumper);
@@ -43,5 +43,5 @@ $scroller->add ($treedumper);
 $window->add ($scroller);
 $window->show_all;
 
-Gtk2->main;
+Gtk3->main;
 
